#include "vi.h"
#include "ViEditView.h"
#include "ViEngine.h"

ViEditView::ViEditView(QWidget *parent)
	: m_mode(CMD), QPlainTextEdit(parent)
{
#if !USE_EVENT_FILTER
	m_viEngine = 0;
#endif
    connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(onCursorPositionChanged()));
}

ViEditView::~ViEditView()
{

}
#if !USE_EVENT_FILTER
void ViEditView::keyPressEvent ( QKeyEvent * event )
{
	if( m_viEngine != 0 && m_viEngine->processKeyPressEvent(event) )
		return;
	QPlainTextEdit::keyPressEvent(event);
}
#endif
void ViEditView::setMode(Mode mode)
{
	if( mode != m_mode ) {
		m_mode = mode;
		emit modeChanged(mode);
		onCursorPositionChanged();
	}
}
void ViEditView::onCursorPositionChanged()
{
	if( mode() == CMD ) {
		QTextCursor cur = textCursor();
		cur.movePosition(QTextCursor::Right, QTextCursor::KeepAnchor);
		QString text = cur.selectedText();
		QChar ch = text.isEmpty() ? QChar(' ') : text[0];
		int wd = fontMetrics().width(ch);
		if( !wd )
			wd = fontMetrics().width(QChar(' '));
		setCursorWidth(wd);
	} else
		setCursorWidth(1);
}
void ViEditView::moveCursor(QTextCursor::MoveOperation mv, int n)
{
	QTextCursor cur = textCursor();
	cur.movePosition(mv, QTextCursor::MoveAnchor, n);
	setTextCursor(cur);
}
